@@ -1,3 +1,4 @@
+import logging
 from os.path import exists
 
 import pandas as pd
@@ -7,7 +8,7 @@ from hoststats.stats import CPU_STATS, DISK_STATS, MEM_STATS, NET_STATS
 
 def validate_csv_data(csv_path, expected_hosts):
     if not exists(csv_path):
-        print(f"Did not find hoststats file at {csv_path}")
+        logging.error(f"Did not find hoststats file at {csv_path}")
         return False
 
     data = pd.read_csv(csv_path)
@@ -20,19 +21,21 @@ def validate_csv_data(csv_path, expected_hosts):
     )
     cols = [c for c in data.columns]
     if cols != expected_cols:
-        print(f"hoststats expected cols {expected_cols}, got {data.columns}")
+        logging.error(
+            f"hoststats expected cols {expected_cols}, got {data.columns}"
+        )
         is_valid = False
 
     # Check hosts list
     hosts = set(data["Host"].unique())
     if set(expected_hosts) != hosts:
-        print(
+        logging.error(
             f"hoststats invalid, expected hosts {expected_hosts}, got {hosts}"
         )
         is_valid = False
 
     if data.isnull().values.any():
-        print("Found null values in hoststats")
+        logging.error("Found null values in hoststats")
         is_valid = False
 
     return is_valid
